OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡Nun se pue escribir nel direutoriu «config»!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Normalmente, esto pue solucionase dando l'accesu d'escritura al sirvidor web nel direutoriu de configuración.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Mas, si prefieres caltener el ficheru config.php como de namás llectura, afita la opción true a «config_is_read_only».",
    "See %s" : "Mira %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "L'aplicación «%1$s» nun ta presente o tien una versión incompatible con esti sirvidor. Revisa'l direutoriu de les aplicaciones.",
    "Sample configuration detected" : "Configuración d'exemplu detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detectóse que se copió la configuración d'exemplu. Esto pue estropiar la to instalación y nun ta sofitao. Llei la documentación enantes de facer cambeos nel ficheru config.php",
    "The page could not be found on the server." : "Nun se pudo atopar la páxina nel sirvidor.",
    "%s email verification" : "Verificación per corréu electrónicu de: %s",
    "Email verification" : "Verificación per corréu electrónicu",
    "Click the following button to confirm your email." : "Calca nel botón siguiente pa confirmar la to direición de corréu electrónicu.",
    "Click the following link to confirm your email." : "Calca nel enllaz siguiente pa confirmar la to direición de corréu electrónicu.",
    "Confirm your email" : "Confirmar la to direición de corrréu electrónicu",
    "Other activities" : "Otres actividaes",
    "%1$s and %2$s" : "%1$s y %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s y %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s y %5$s",
    "Enterprise bundle" : "Paquete empresarial",
    "Groupware bundle" : "Paquete pa grupos",
    "Hub bundle" : "Paquete pa hubs",
    "Public sector bundle" : "Paquete pal sector públicu",
    "Social sharing bundle" : "Paquete social",
    "PHP %s or higher is required." : "Ríquese la versión %s o superior de PHP.",
    "PHP with a version lower than %s is required." : "Ríquese una versión de PHP inferior a la %s.",
    "%sbit or higher PHP required." : "Ríquese PHP de %s bits o superior.",
    "The following architectures are supported: %s" : "Les arquiteutures siguientes son compatibles: %s",
    "The following databases are supported: %s" : "Les bases de datos siguientes son compatibles: %s",
    "The command line tool %s could not be found" : "Nun se pudo atopar la ferramienta de llinia de comandos «%s»",
    "The library %s is not available." : "La biblioteca «%s» nun ta disponible.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Ríquese una biblioteta «%1$s» con una versión superior a la %2$s. La versión qu'hai disponible ye la %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Ríquese una biblioteta «%1$s» con una versión inferior a la %2$s. La versión qu'hai disponible ye la %3$s.",
    "The following platforms are supported: %s" : "Les plataformes siguientes son compatibles: %s",
    "Server version %s or higher is required." : "Ríquese una versión del sirvidor %s o superior.",
    "Server version %s or lower is required." : "Ríquese una versión del sirvidor %s o inferior.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "La cuenta que tien la sesión aniciada ha ser d'alministración, un sodominiu o tener un permisu especial p'acceder a esta opción",
    "Logged in account must be an admin or sub admin" : "La cuenta que tien la sesión aniciada ha ser d'alministración o un sodominiu",
    "Logged in account must be an admin" : "La cuenta que tien la sesión aniciada ha ser d'alministración",
    "Wiping of device %s has started" : "Anicióse la llimpieza del preséu «%s»",
    "Wiping of device »%s« has started" : "Anicióse la llimpieza del preséu «%s»",
    "»%s« started remote wipe" : "«%s» anició la llimpieza remota",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Un preséu o una aplicación «%s» anició'l procesu de llimpieza remota. Vas recibir un mensaxe per corréu electrónicu namás que fine",
    "Wiping of device %s has finished" : "La llimipieza del preséu «%s» finó",
    "Wiping of device »%s« has finished" : "La llimipieza del preséu «%s» finó",
    "»%s« finished remote wipe" : "«%s» finó la llimpieza remota",
    "Device or application »%s« has finished the remote wipe process." : "Un preséu o una aplicación «%s» finó'l procesu de llimpieza remota.",
    "Remote wipe started" : "Anicióse la llimpieza remota",
    "A remote wipe was started on device %s" : "Anicióse la llimpieza remota nel preséu «%s»",
    "Remote wipe finished" : "La llimpieza remota falló",
    "The remote wipe on %s has finished" : "La llimpieza remota en «%s» finó",
    "Authentication" : "Autenticación",
    "Unknown filetype" : "El tipu de ficheru ye inválidu",
    "Invalid image" : "La imaxe ye inválida",
    "Avatar image is not square" : "La imaxe del avatar nun ye cuadrada",
    "Files" : "Ficheros",
    "View profile" : "Ver el perfil",
    "Local time: %s" : "Hora llocal: %s",
    "today" : "güei",
    "tomorrow" : "mañana",
    "yesterday" : "ayeri",
    "_in %n day_::_in %n days_" : ["en %n día","en %n díes"],
    "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n díes"],
    "next month" : "el mes que vien",
    "last month" : "el mes pasáu",
    "_in %n month_::_in %n months_" : ["en %n mes","en %n meses"],
    "_%n month ago_::_%n months ago_" : ["hai %n mes","hai %n meses"],
    "next year" : "l'añu pasáu",
    "last year" : "l'añu que vien",
    "_in %n year_::_in %n years_" : ["en %n añu","en %n años"],
    "_%n year ago_::_%n years ago_" : ["hai %n añu","hai %n años"],
    "_in %n hour_::_in %n hours_" : ["en %n hora","en %n hores"],
    "_%n hour ago_::_%n hours ago_" : ["hai %n hora","hai %n hores"],
    "_in %n minute_::_in %n minutes_" : ["en %n minutu","en %n minutos"],
    "_%n minute ago_::_%n minutes ago_" : ["hai %n minutu","hai %n minutos"],
    "in a few seconds" : "en dellos segundos",
    "seconds ago" : "hai segundos",
    "Empty file" : "Ficheru baleru",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulu cola ID %s nun esiste. Actívalu na configuración de les aplicaciones o ponte en contautu cola alminsitración.",
    "Dot files are not allowed" : "Nun se permiten los ficheros que comiencen per un puntu",
    "File already exists" : "El ficheru yá esiste",
    "Invalid path" : "El camín ye inválidu",
    "Failed to create file from template" : "Nun se pudo crear el ficheru de la plantía",
    "Templates" : "Plantíes",
    "Filename contains at least one invalid character" : "El nome del ficheru contién polo menos un caráuter inváldu",
    "Empty filename is not allowed" : "Nun se permite que'l nome del ficheru tea baleru",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Nun se pue instalar l'aplicación «%s» porque nun se pue lleer el ficheru appinfo",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Nun se pue instalar l'aplicación «%s» porque nun ye compatible con esta versión del sirvidor.",
    "__language_name__" : "Asturianu",
    "This is an automatically sent email, please do not reply." : "Esti mensaxe unvióse automáticamente, nun respuendas.",
    "Help & privacy" : "Ayuda y privacidá",
    "Appearance and accessibility" : "Aspeutu ya accesibilidá",
    "Apps" : "Aplicaciones",
    "Personal settings" : "Configuración personal",
    "Administration settings" : "Configuración de l'alministración",
    "Settings" : "Configuración",
    "Log out" : "Zarrar la sesión",
    "Accounts" : "Cuentes",
    "Email" : "Corréu electrónicu",
    "Mail %s" : "Unviar per corréu electrónicu «%s»",
    "Fediverse" : "Fediversu",
    "View %s on the fediverse" : "Ver «%s» nel fediversu",
    "Phone" : "Teléfonu",
    "Call %s" : "Llamar a %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Ver «%s» en Twitter",
    "Website" : "Sitiu web",
    "Visit %s" : "Visitar «%s»",
    "Address" : "Direición",
    "Profile picture" : "Semeya del perfil",
    "About" : "Tocante a",
    "Display name" : "Nome visible",
    "Headline" : "Titular",
    "Organisation" : "Organización",
    "Role" : "Rol",
    "Unknown account" : "Cuenta desconocida",
    "Additional settings" : "Configuración adicional",
    "Enter the database Login and name for %s" : "Introduz los datos d'accesu y el nome de la base de datos pa: %s",
    "Enter the database Login for %s" : "Introduz los datos d'accesu de la base de datos pa: %s",
    "Enter the database name for %s" : "Introduz el nome de la base de datos pa: %s",
    "You cannot use dots in the database name %s" : "Nun pues usar puntos nel nome de la base de datos «%s»",
    "MySQL Login and/or password not valid" : "Los datos d'accesu/contraseña de MySQL nun son válidos",
    "You need to enter details of an existing account." : "Tienes d'introducir los detalles d'una cuenta esistente.",
    "Oracle connection could not be established" : "Nun se pudo configurar la conexón d'Oracle",
    "Oracle Login and/or password not valid" : "La cuenta y/o contraseña d'Oracle nun ye válida",
    "PostgreSQL Login and/or password not valid" : "La cuenta y/o contraseña de PostgreSQL nun ye válida",
    "For the best results, please consider using a GNU/Linux server instead." : "Pa consiguir los meyores resultaos, usa un sirvidor de GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Paez qu'esta instancia de Nextcloud «%s» execútase sobre un entornu PHP de 32 bits y la opción open_basedir ta configurada en php.ini. Esto va orixinar problemes con ficheros superiores a 4GB y ye mui desaconseyable.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Quita la opción «open_basedir» de php.ini o cambia a PHP de 64 bits.",
    "Set an admin Login." : "Afitar la cuenta d'alministración",
    "Set an admin password." : "Afitar una contraseña d'alministrador",
    "Cannot create or write into the data directory %s" : "Nun se pue crear o escribir nel direutoriu de datos «%s»",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend de compartición «%s» ha implmentar la interfaz OCP\\Share_Backend",
    "Sharing backend %s not found" : "Nun s'atopó'l backend de compartición «%s»",
    "Sharing backend for %s not found" : "Nun s'atopó'l backend de compartición pa: %s",
    "%1$s via %2$s" : "%1$s per %2$s",
    "Unknown share type" : "Tipu de compartición desconocida",
    "You are not allowed to share %s" : "Nun tienes permisu pa compartir «%s»",
    "Cannot increase permissions of %s" : "Nun se pue amentar los permisos de: %s",
    "Files cannot be shared with create permissions" : "Los ficheros nun se pue compartir colos permisos de creación",
    "Expiration date is in the past" : "La data de caducidá ta nel pasáu",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Nun se pue afitar una data de caducidá de más de %n día nel futuru","Nun se pue afitar una data de caducidá de más de %n díes nel futuru"],
    "Sunday" : "Domingu",
    "Monday" : "Llunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Xueves",
    "Friday" : "Vienres",
    "Saturday" : "Sábadu",
    "Sun." : "Dom.",
    "Mon." : "Llu.",
    "Tue." : "Mar.",
    "Wed." : "Mié.",
    "Thu." : "Xue.",
    "Fri." : "Vie.",
    "Sat." : "Sáb.",
    "Su" : "Do",
    "Mo" : "Ll",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Xu",
    "Fr" : "Vi",
    "Sa" : "Sá",
    "January" : "Xineru",
    "February" : "Febreru",
    "March" : "Marzu",
    "April" : "Abril",
    "May" : "Mayu",
    "June" : "Xunu",
    "July" : "Xunetu",
    "August" : "Agostu",
    "September" : "Setiembre",
    "October" : "Ochobre",
    "November" : "Payares",
    "December" : "Avientu",
    "Jan." : "Xin.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Xun.",
    "Jul." : "Xnt.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Och.",
    "Nov." : "Pay.",
    "Dec." : "Avi.",
    "A valid password must be provided" : "Ha fornise una contraseña válida",
    "a safe home for all your data" : "un llugar seguru pa los datos personales",
    "Application is not enabled" : "L'aplicación nun ta activada",
    "Authentication error" : "Error de l'autenticación",
    "Your data directory is not writable." : "Nun se pue escribir nel to direutoriu de datos.",
    "Please ask your server administrator to install the module." : "Pidi a l'alministración del sirvidor qu'instale'l módulu.",
    "Your data directory is invalid." : "El to direutoriu de datos ye inválidu.",
    "Action \"%s\" not supported or implemented." : "L'aición «%s» nun ta sofitada o implementada.",
    "Authentication failed, wrong token or provider ID given" : "L'autenticación falló, apurriéronse un pase o una ID de fornidor incorreutos",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Falten parámetros pa completar la solicitú. Los parámetros que falten: «%s»",
    "Storage is temporarily not available" : "L'almacenamientu nun ta disponible temporalmente",
    "Confirmation" : "Confirmación",
    "Writing style" : "Estilu d'escritura",
    "Source material" : "Material d'orixe",
    "Generate image" : "Xenerar una imaxe",
    "Chat" : "Charra",
    "Text" : "Testu",
    "Summarize" : "Resume",
    "Summary" : "Resume",
    "Extract topics" : "Estrayer temes",
    "Translate" : "Traducir",
    "Target language" : "Llingua de destín",
    "Result" : "Resultáu",
    "Summarizes text by reducing its length without losing key information." : "Resume'l testu amenorgando la so llongura ensin perder la información importante.",
    "Extracts topics from a text and outputs them separated by commas." : "Estrái temes d'un testu y devuélvelos separtaos per comes.",
    "Education Edition" : "Edición educativa",
    "File name is a reserved word" : "El nome de ficheru ye una pallabra acutada",
    "File name contains at least one invalid character" : "El nome del ficheru contién polo menos un caráuter inváldu",
    "File name is too long" : "El nome del ficheru ye mui llongu",
    "Users" : "Usuarios",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartío «%2$s» contigo y quier amestar:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartío «%2$s» contigo y quier amestar",
    "»%s« added a note to a file shared with you" : "«%s» amestó una nota a un ficheru compartío contigo",
    "Open »%s«" : "Abrir «%s»",
    "%1$s shared »%2$s« with you" : "%1$s compartió «%2$s» contigo",
    "%1$s shared »%2$s« with you." : "%1$s compartió «%2$s» contigo.",
    "Click the button below to open it." : "Calca nel botón p'abrilo.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrate de que'l ficheru llamáu «.ocdata» ta nel raigañu del direutoriu de datos."
},
"nplurals=2; plural=(n != 1);");
